==============================
Django library for Mailman UIs
==============================

This package contains libraries and templates for Django-based interfaces
interacting with Mailman.

To use this application, add it to the ``INSTALLED_APPS`` list in your Django
server's settings file.


License
=======

Django-mailman is licensed under the
`GPL v3.0 <http://www.gnu.org/licenses/gpl-3.0.html>`_

Copyright (C) 2017 by the Free Software Foundation, Inc.
